options nocenter linesize=132;
%include 'daspline.prg' /nosource2 ;
%include 'dshide.prg' /nosource2 ;
filename inf 'pbc.dat';

data anal;
  infile inf obs=312; 
  input n time delta trt age sex ascites hepa spider edema bili chol
      albumin copper phosphat sgot trig platelet proth stage;
  lbili=log(bili);
run;

%daspline(bili,data=anal,nk=4,knot1=0.8 1.35 3.45 7.2)

data anal ;
   set anal;
   &_bili      /* generate spline variables for bili */
run;

  /* store min, max and increment value for bili 
     in macro variable for later use 
  */

proc univariate data=anal;
   var bili;
   output out=minmax min=x0_1 max=x100_1;
run;

data minmax;
   set minmax;
   biliinc=(x100_1 - x0_1)/100;
   call symput('bilimax',x100_1) ;
   call symput('bilimin',x0_1);
   call symput('biliinc',biliinc);
run;


  /* run spline models and plots 
     the x variable by the log hazzard ratio 
  */

proc phreg nosummary data=anal
    outest=anal2(keep=bili bili1 bili2);
model time*delta(0)=bili bili1 bili2;
title1 'Cubic Spline (4 knots)';
run;

       * output a data set with the x values to be plotted    ;
       * the x-values will cover the entire range of the data ;
       *                                                      ;

      data est;
            do bili=&bilimin to &bilimax by &biliinc;
               &_bili
               output;
            end;
      run;





       * calculate the log hazzard ratio for the x-values ;
       * output above                                     ;

      proc iml ;
         reset print ;
         use anal2 ;
         read all into _beta_ ;
         _beta_=_beta_` ;
         close anal2 ;
         use est ;
         read all into _x_ ;
         close est ;
         _xbeta_=_x_*_beta_ ;
         _z_=_x_[,1 ] || _xbeta_ ;
         c={'bili' 'splntran'} ;
         create pl from _z_[colname=c] ;
         append from _z_ ;
         close pl ;
      quit ;

     title1;
     title2 h=1.6 f=triplex "Estimated Cubic Spline Transformation (4 knots)" ;
proc gplot data=pl ;

   plot splntran*bili / href= 1.4 2.8 5 6.5;

   symbol1 i=join l=1;
   label splntran="Log Hazard Ratio"
         bili ="bilirubin" ;
   run;

/* compare to the log transformation of bili */

proc phreg nosummary data=anal
  outest=anal2(keep=lbili);
   model time*delta(0)=lbili;
run;    
    

      data est;
            do bili=&bilimin to &bilimax by &biliinc;
               lbili=log(bili);
               output;
            end;
      run;














      proc iml ;
         reset print ;
         use anal2 ;
         read all into _beta_ ;
         _beta_=_beta_` ;
         close anal2 ;
         use est ;
         read all into _x_ ;
         close est ;
         _xbeta_=_x_[,2]*_beta_ ;
         _z_=_x_[,1 ] || _xbeta_ ;
         c={'bili' 'splntran'} ;
         create pll from _z_[colname=c] ;
         append from _z_ ;
         close pll ;
      quit ;

data pl;
  set pl;
  type=1;
run;
data pll;
  set pll;
  type=2;
run;

data b;
  set pl pll;
run;
 
goptions reset=(symbol);

     title1;
     title2 h=1.6 f=triplex "Estimated Cubic Spline and Log Transformation" ;
    proc gplot data=b ;

      plot splntran*bili=type / href= 1.4 2.8 5 6.5;
*      plot splntran*bili=type / href= 0.8 1.35 3.45 7.2;
*      plot splntran*bili=type / href= 0.5 0.8 3.45 14.1;
*      plot splntran*bili=type / href= 0.8 1.4 6.7 16.2;

     symbol1 c=default i=join l=1;
     symbol2 c=default i=join l=3;
     label splntran="Log Hazard Ratio"
            bili ="bilirubin" ;
   run;


